# COSMIC
cosmic (Compact Object Synthesis and Monte Carlo Investigation Code) 

cosmic is a rapid binary population synthesis suite with a special purpose of generating realistic Milky Way compact binary populations. cosmic can also be used to evolve binaries with BSE in a python environment. 

cosmic currently implements binary evolutionary processes using BSE (Hurley+2002). Several modifications have been applied to BSE to account for recent updates to binary evolution especially important to compact binary formation (e.g. metallicity-dependent stellar winds or black hole natal kick strengths). For a detailed discussion of these modifications, see Breivik+2018 in prep.

<https://cosmic-popsynth.github.io/>

# Installation

The easiest method to install cosmic is using pip directly:

```
pip install cosmic-popsynth
```

[![Build Status](https://travis-ci.org/COSMIC-PopSynth/COSMIC.svg?branch=develop)](https://travis-ci.org/COSMIC-PopSynth/COSMIC)

[![Coverage Status](https://coveralls.io/repos/github/COSMIC-PopSynth/COSMIC/badge.svg?branch=develop)](https://coveralls.io/github/COSMIC-PopSynth/COSMIC?branch=develop)

